@@ -1,4 +1,4 @@
-/* $Id: libacpi.c 1974 2006-09-06 09:50:27Z nick $
+/* $Id: libacpi.c 3002 2007-08-17 18:38:04Z nick $
  *
  * Copyright (c) 2002 Costantino Pistagna <valvoline@vrlteam.org>
  * Copyright (c) 2003 Noberasco Michele <2001s098@educ.disi.unige.it>
@@ -190,10 +190,12 @@ int check_acpi(void)
 #ifdef __linux__
   FILE *acpi;
 
-  if (!(acpi = fopen ("/proc/acpi/info", "r")))
+  if (!(acpi = fopen ("/proc/acpi/info", "r"))
+      && !(acpi = fopen ("/sys/module/acpi/parameters/acpica_version", "r")))
   {
 #ifdef DEBUG
-	  printf("DBG:no acpi: /proc/acpi/info not found!\n");
+	  printf("DBG:no acpi: /proc/acpi/info or "
+             "/sys/module/acpi/parameters/acpica_version not found!\n");
 #endif
     return 1;
   }
